@@ -20,8 +20,8 @@ try:
     @pytest.fixture
     @async_generator
     async def task_publisher(connection: aio_pika.Connection):
-        exchange_name = '{}.{}'.format(__file__, uuid.uuid4())
-        task_queue_name = '{}.{}'.format(__file__, uuid.uuid4())
+        exchange_name = f'{__file__}.{uuid.uuid4()}'
+        task_queue_name = f'{__file__}.{uuid.uuid4()}'
 
         task_pub = rmq.RmqTaskPublisher(
             connection, queue_name=task_queue_name, exchange_name=exchange_name, testing_mode=True
@@ -33,8 +33,8 @@ try:
     @pytest.fixture
     @async_generator
     async def task_queue(connection: aio_pika.Connection):
-        exchange_name = '{}.{}'.format(__file__, uuid.uuid4())
-        task_queue_name = '{}.{}'.format(__file__, uuid.uuid4())
+        exchange_name = f'{__file__}.{uuid.uuid4()}'
+        task_queue_name = f'{__file__}.{uuid.uuid4()}'
 
         task_pub = rmq.RmqTaskQueue(
             connection, queue_name=task_queue_name, exchange_name=exchange_name, testing_mode=True
